==> cafe-pdf-1.0.5.tgz: package/README.md <==
# Cafe-PDF

> Render PDF files on Vue pages using pdf.js, supporting text rendering, lazy loading, paging, scaling, and printing.

* 😊 Vue 2.0 + [`pdf.js 2.0.943`](https://github.com/mozilla/pdf.js);
* 😂 Support for modern browsers;
* 🀄 [中文文档](./README-zh.md)

## Install

```shell
npm install cafe-pdf --save
```

## Quick Start
```js
import cafePdf from 'cafe-pdf'
import 'cafe-pdf/package/cafe-pdf.css'
Vue.use(cafePdf)
```

## Example

Demo：[http://demo.const.team/pdf/](http://demo.const.team/pdf/)

Note: the use of print, need to cooperate with the print style.

```vue
<template>
  <cafe-pdf ref="pdf" @on-loaded="load" @on-scroll="scroll" src="https://mozilla.github.io/pdf.js/web/compressed.tracemonkey-pldi-09.pdf">
    <template slot="header">
      <button :disabled="current<=1" @click="gopage('pre')">pre page</button>
      <input readonly type="text" v-model="current">
      <button :disabled="current>=sum" @click="gopage('next')">next page</button>
      <select v-model="scale" @change="setScale">
        <option value="auto">auto</option>
        <option value="page-actual">actual</option>
        <option value="page-fit">fit</option>
        <option value="page-width">width</option>
        <option value="0.50">50%</option>
        <option value="0.75">75%</option>
        <option value="1">100%</option>
        <option value="1.25">125%</option>
        <option value="1.50">150%</option>
        <option value="1.75">175%</option>
        <option value="2">200%</option>
        <option value="3">300%</option>
        <option value="4">400%</option>
      </select>
      <button @click="print">print</button>
    </template>
  </cafe-pdf>
</template>

<script>
export default {
  name: 'pdf',
  data() {
    return {
      sum: null,
      scale: 1,
      current: 1
    };
  },
  components: {},
  methods: {
    load(val) {
      console.log(val);
      this.sum = val;
    },
    setScale() {
      this.$refs.pdf.zoom(this.scale);
    },
    scroll(val) {
      this.current = val;
    },
    gopage(type) {
      if (type == 'next') {
        this.$refs.pdf.changePage(++this.current);
      } else {
        this.$refs.pdf.changePage(--this.current);
      }
    },
    print() {
      this.$refs.pdf.printPdf();
    }
  }
};
</script>

<style>
html,body{
  width: 100%;
  height: 100%;
}
* {
  margin: 0;
  padding: 0;
}
@media print {
  #app {
    display: none;
  }
}
</style>
```

## Attributes
| Attribute      | Description          | Type      | Accepted Values                           | Default  |
|---------- |-------------- |---------- |--------------------------------  |-------- |
| src | pdf source | string | — | — |
| width | pdf width | string | — | 100% |
| height | pdf height | string | — | 100% |
| useOnlyCssZoom | only use css zoom | boolean | — | false |
| autoWidth | Whether to scale PDF to container width during initialization | boolean | — | false |
| textLayerMode | Render in text mode, 0 use canvas，1 use text mode | number | 0/1 | 0 |

## Events
| Event Name | Description | Parameters |
| ---- | ---- | ---- |
| on-loaded | Initialize event | Total number of pages |
| on-scroll | Triggered when scrolling pdf | Current pages |

## Methods
| Method | Description | Parameters |
| ---- | ---- | ---- |
| zoom | zoom | Scaling |
| changePage | PDF change page | page |
| printPdf | Print all pdf | scale |


## Slot
| name | Description |
|------|--------|
| header | header slot |
| footer | footer slot |

==> cafe-pdf-1.0.6.tgz: package/README.md <==
# Cafe-PDF

![NPM Publish](https://github.com/wangdaodao/cafe-pdf/actions/workflows/npm-publish.yml/badge.svg) ![NPM version](https://img.shields.io/npm/v/cafe-pdf.svg) ![GitHub stars](https://img.shields.io/github/stars/wangdaodao/cafe-pdf.svg) ![GitHub issues](https://img.shields.io/github/issues/wangdaodao/cafe-pdf.svg) ![GitHub forks](https://img.shields.io/github/forks/wangdaodao/cafe-pdf.svg)

> Render PDF files on Vue pages using pdf.js, supporting text rendering, lazy loading, paging, scaling, and printing.

* 😊 Vue 2.0 + [`pdf.js 2.0.943`](https://github.com/mozilla/pdf.js);
* 😂 Support for modern browsers;
* 🀄 [中文文档](./README-zh.md)

## Install

```shell
npm install cafe-pdf --save
```

## Quick Start
```js
import cafePdf from 'cafe-pdf'
import 'cafe-pdf/package/cafe-pdf.css'
Vue.use(cafePdf)
```

## Example

Demo：[http://demo.const.team/pdf/](http://demo.const.team/pdf/)

Note: the use of print, need to cooperate with the print style.

```vue
<template>
  <cafe-pdf ref="pdf" @on-success="load" @on-scroll="scroll" :src="src">
    <template slot="header">
      pdf-src:<input type="text" v-model="src" @change="fileChanged">
    </template>
    <template slot="footer">
      <button :disabled="current<=1" @click="gopage('pre')">pre</button>
      <input type="number" :min="1" :max="sum" v-model.number="current" @change="pageChange(current)">
      <button :disabled="current>=sum" @click="gopage('next')">next</button>
      <select v-model="scale" @change="setScale">
        <option value="auto">auto</option>
        <option value="page-actual">actual</option>
        <option value="page-fit">fit</option>
        <option value="page-width">width</option>
        <option value="0.50">50%</option>
        <option value="0.75">75%</option>
        <option value="1">100%</option>
        <option value="1.25">125%</option>
        <option value="1.50">150%</option>
        <option value="1.75">175%</option>
        <option value="2">200%</option>
        <option value="3">300%</option>
        <option value="4">400%</option>
      </select>
      <button @click="print">print</button>
    </template>
  </cafe-pdf>
</template>

<script>
export default {
  name: 'app',
  data() {
    return {
      src: 'https://mozilla.github.io/pdf.js/web/compressed.tracemonkey-pldi-09.pdf',
      sum: null,
      scale: 1,
      current: 1
    };
  },
  components: {},
  methods: {
    fileChanged() {
      this.file = this.src;
    },
    load(val) {
      this.sum = val._pdfInfo.numPages;
    },
    setScale() {
      this.$refs.pdf.zoom(this.scale);
    },
    scroll(val) {
      this.current = val;
    },
    gopage(type) {
      if (type == 'next') {
        this.$refs.pdf.changePage(++this.current);
      } else {
        this.$refs.pdf.changePage(--this.current);
      }
    },
    pageChange(val) {
      this.$refs.pdf.changePage(val);
    },
    print() {
      this.$refs.pdf.printPdf();
    }
  }
};
</script>

<style>
html,
body {
  width: 100%;
  height: 100%;
}
* {
  margin: 0;
  padding: 0;
}
#app {
  color: #2c3e50;
  width: 100%;
  height: 100%;
}
@media print {
  #app {
    display: none;
  }
}
</style>
```

## Attributes
| Attribute      | Description          | Type      | Accepted Values                           | Default  |
|---------- |-------------- |---------- |--------------------------------  |-------- |
| src | pdf source | string | — | — |
| width | pdf width | string | — | 100% |
| height | pdf height | string | — | 100% |
| useOnlyCssZoom | only use css zoom | boolean | — | false |
| autoWidth | Whether to scale PDF to container width during initialization | boolean | — | false |
| textLayerMode | Render in text mode, 0 use canvas，1 use text mode | number | 0/1 | 0 |

## Events
| Event Name | Description | Parameters |
| ---- | ---- | ---- |
| on-success | success event | pdf obj |
| on-error | error event | error |
| on-scroll | Triggered when scrolling pdf | Current pages |

## Methods
| Method | Description | Parameters |
| ---- | ---- | ---- |
| zoom | zoom | Scaling |
| changePage | PDF change page | page |
| printPdf | Print all pdf | scale |


## Slot
| name | Description |
|------|--------|
| header | header slot |
| footer | footer slot |
